<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" encoding="utf-8" indent="yes"/>
	<xsl:template match="/">
		<xsl:for-each select="UserInterfaceSpecification">
			<UserInterfaceSpecification>
				<!-- Namespace 
				<xsl:for-each select="./namespace::*">
					<xsl:choose>
						<xsl:when test="name()='xsi'">
							<xsl:attribute name="xsi" namespace="http://www.w3.org/2001/XMLSchema">http://www.w3.org/2001/XMLSchema</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>-->
				<!-- Attribute -->
				<xsl:for-each select="./attribute::*">
					<xsl:choose>
						<xsl:when test="name()='useNavigationTree'">
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
				<xsl:if test="not(boolean(./@versionNo))">
					<xsl:attribute name="versionNo">1.0</xsl:attribute>
				</xsl:if>
				<xsl:if test="not(boolean(./@allowSavingWithErrors))">
					<xsl:attribute name="allowSavingWithErrors">false</xsl:attribute>
				</xsl:if>
				<!-- Component -->
				<xsl:for-each select="./child::component">
					<xsl:apply-templates select="."/>
				</xsl:for-each>
				<!-- Virtual component -->
				<xsl:for-each select="./child::virtualComponent">
					<xsl:apply-templates select="."/>
				</xsl:for-each>
			</UserInterfaceSpecification>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="component">
		<component>
			<!--Attribute lesen und kopieren-->
			<xsl:for-each select="./@*">
				<xsl:copy/>
			</xsl:for-each>
			<xsl:apply-templates select="./child::*"/>
		</component>
	</xsl:template>

	<xsl:template match="virtualComponent">
		<virtualComponent>
			<xsl:for-each select="./@*">
				<xsl:copy/>
			</xsl:for-each>
			<xsl:apply-templates select="./child::*"/>
		</virtualComponent>
	</xsl:template>

	<xsl:template match="SimpleType|SimpleTypeList|SimpleGroup|SimpleGroupList|ComplexGroup|ComplexGroupList">
		<xsl:for-each select="../*">
			<xsl:apply-templates select="./child::*"/>
			<!--Template Style + behaviour...-->
		</xsl:for-each>
	</xsl:template>
	<!-- Template für style-Teil-->
	<xsl:template match="style">
		<style>
			<xsl:if test="../../@xpath='/ExpertOrder'">
				<mode>
					<xsl:attribute name="useNavigationTree">
						<xsl:value-of select="../../../@useNavigationTree"/>
					</xsl:attribute>
				</mode>
			</xsl:if>
			<xsl:for-each select="./child::*">
				<xsl:choose>
					<xsl:when test="./self::label">
						<xsl:copy-of select="./parent::style/label"/>
					</xsl:when>
					<xsl:when test="./self::choices">
						<xsl:copy-of select="./parent::style/choices"/>
					</xsl:when>
					<xsl:when test="./self::layout">
						<xsl:copy-of select="./parent::style/layout"/>
					</xsl:when>
					<xsl:when test="./self::size">
						<xsl:copy-of select="./parent::style/size"/>
					</xsl:when>
					<xsl:when test="./self::bean">
						<xsl:apply-templates select="./parent::style/bean"/>
					</xsl:when>
					<xsl:when test="./self::header">
						<xsl:copy-of select="./parent::style/header"/>
					</xsl:when>
					<xsl:when test="./self::mode">
						<xsl:copy-of select="./parent::style/mode"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="node()"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</style>
	</xsl:template>	
	<!-- Template für bean-Teil-->
	<xsl:template match="bean">
		<plugIn>
			<xsl:for-each select="./@*">
				<xsl:choose>
					<xsl:when test=".='com.swissre.g10.eval.gui.tool.G10JAXFrontOCSVisualizer'">
						<xsl:attribute name="class">com.swissre.ric.client.gui.jaxfront.RICOCSVisualizer</xsl:attribute>
					</xsl:when>
					<xsl:when test=".='com.swissre.g10.eval.gui.tool.G10JAXFrontFinPeriodVisualizer'">
						<xsl:attribute name="class">com.swissre.ric.client.gui.jaxfront.RICFinPeriodVisualizer</xsl:attribute>
					</xsl:when>
					<xsl:when test=".='com.swissre.g10.eval.gui.tool.G10JAXFrontTiDiVisualizer'">
						<xsl:attribute name="class">com.swissre.ric.client.gui.jaxfront.RICTiDiVisualizer</xsl:attribute>
					</xsl:when>
					<xsl:when test=".='com.swissre.g10.eval.gui.tool.G10JAXFrontTimeStampVisualizer'">
						<xsl:attribute name="class">com.swissre.ric.client.gui.jaxfront.RICTimeStampVisualizer</xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
			<xsl:for-each select="./child::param">
				<!--<xsl:if test="param">-->
				<param>
					<xsl:for-each select="./attribute::*">
						<xsl:copy/>
					</xsl:for-each>
					<xsl:attribute name="value">
						<xsl:value-of select="."/>
					</xsl:attribute>
				</param>
			</xsl:for-each>
			<xsl:for-each select="./child::action">
				<xsl:apply-templates select="."/>
			</xsl:for-each>
		</plugIn>
	</xsl:template>
	<!-- Template für behavior-Teil-->
	<xsl:template match="behaviour">
		<behaviour>
			<xsl:for-each select="child::navigation">
				<xsl:copy-of select="."/>
			</xsl:for-each>
			<xsl:for-each select="./child::rule">
				<rule>
					<xsl:copy-of select="./child::event"/>
					<xsl:for-each select="./child::simpleCondition">
						<condition>
							<xsl:attribute name="useToggle">
								<xsl:value-of select="@useToggle"/>
							</xsl:attribute>
							<xsl:attribute name="showError">
								<xsl:value-of select="@showError"/>
							</xsl:attribute>
							<formulaExpression>
								<xsl:attribute name="expression">.<xsl:value-of select="@operator"/>&quot;<xsl:value-of select="."/>&quot;</xsl:attribute>
							</formulaExpression>
						</condition>
					</xsl:for-each>
					<xsl:for-each select="./child::complexCondition">
						<condition>
							<xsl:attribute name="showError">
								<xsl:value-of select="@showError"/>
							</xsl:attribute>
							<formulaExpression>
								<xsl:choose>
									<xsl:when test="../../../../../component/@xpath='/ExpertOrder/ControlSection/DueDate'">
										<xsl:attribute name="expression">$noPastDate</xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="expression">
											<xsl:value-of select="./child::formula"/>
										</xsl:attribute>
										<xsl:for-each select="./child::variable">
											<xsl:copy-of select="."/>
										</xsl:for-each>
									</xsl:otherwise>
								</xsl:choose>
							</formulaExpression>
						</condition>
					</xsl:for-each>
					<xsl:for-each select="./child::action">
						<xsl:apply-templates select="."/>
					</xsl:for-each>
				</rule>
			</xsl:for-each>
			<xsl:for-each select="./child::formulaExpression">
				<formulaExpression>
					<xsl:attribute name="expression">
						<xsl:value-of select="./child::formula"/>
					</xsl:attribute>
					<xsl:for-each select="./child::variable">
						<xsl:copy-of select="."/>
					</xsl:for-each>
				</formulaExpression>
			</xsl:for-each>
		</behaviour>
	</xsl:template>

	<xsl:template match="action">
		<action>
			<xsl:for-each select="./attribute::*">
				<xsl:copy/>
			</xsl:for-each>
			<xsl:for-each select="./child::propertyChange">
				<propertyChange>
					<formulaExpression>
						<xsl:attribute name="expression">
							<xsl:value-of select="./child::stringExpression/child::formula"/>
						</xsl:attribute>
						<xsl:for-each select="./child::stringExpression/child::variable">
							<xsl:copy-of select="."/>
						</xsl:for-each>
					</formulaExpression>
				</propertyChange>
			</xsl:for-each>
			<xsl:for-each select="./child::uiAction">
				<uiAction>
					<xsl:for-each select="./attribute::*">
						<xsl:copy/>
					</xsl:for-each>
					<xsl:for-each select="./child::param">
						<param>
							<xsl:choose>
								<xsl:when test="../@methodName='addDependent'">
									<xsl:for-each select="./attribute::*">
										<xsl:choose>
											<xsl:when test=".='Visualizer'">
												<xsl:attribute name="type">Type</xsl:attribute>
											</xsl:when>
											<xsl:otherwise>
												<xsl:copy/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:for-each>
								</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="attribute::*">
										<xsl:copy/>
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:attribute name="value">
								<xsl:value-of select="."/>
							</xsl:attribute>
						</param>
					</xsl:for-each>
				</uiAction>
			</xsl:for-each>
			<xsl:for-each select="./child::structureChange">
				<xsl:copy-of select="."/>
			</xsl:for-each>
		</action>
	</xsl:template>
</xsl:stylesheet><!-- Stylus Studio meta-information - (c)1998-2001 eXcelon Corp.
<metaInformation>
<scenarios ><scenario default="yes" name="Scenario1" userelativepaths="yes" url="L1000.xui" htmlbaseurl="file://d:\download\xui\" processortype="internal" commandline="" additionalpath="" additionalclasspath="" postprocessortype="none" postprocesscommandline="" postprocessadditionalpath="" postprocessgeneratedext=""/></scenarios><MapperInfo  srcSchemaPath="xui0&#x2D;9.xsd" srcSchemaRoot="action" srcSchemaPathIsRelative="yes" destSchemaPath="xui1&#x2D;0.xsd" destSchemaRoot="action" destSchemaPathIsRelative="yes" />
</metaInformation>
-->